function [xt,xb,yo,B,R,d,G]=init_ressaut()
%%%%%%%%%%%%%%%%%
%  init_ressaut
%
% Initialisation des parametres de l'experience jumelles
% 
% ncont = 1 car  x = [hR]
% nobs =  1 car  y = [W]
%
% xt : etat vrai
% xb : ebauche
% yo : observations
% B : covariance d'erreur d'ebauche 
% R : covariance d'erreur d'observatin 
% d : innovation
% G : operateur d'observation linearise
%
%
% calG_ressaut.sci : operateur d'observation
% Glin_ressaut.sci : matrice operateur d'observation linearise
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%  

% Variables globales 
global jalea % numero du tirage aleatoire 
global hL UL % hauteur et vitesse a gauche


%%%%%%%%%%%%%%%%%%
% MODIFIER ICI LES PARAMETRES  %
%%%%%%%%%%%%%%%%
hRt=17;  % etat vrai en cm, Ref : hRt=17 cm 
hRb=18;   % ebauche, Ref : hRb=18 cm
hL=5;    % hauteur amont en cm
g=9.81;   % gravite
UL=sqrt(g*(hL+hRt)/(2*hL*hRt))*(hRt-hL)/10; % vitesse amont en m/s
Wt=calG_ressaut(hRt); % observation de l'etat vraie Wt=-hL*UL/(hRt-hL); 
Wb=calG_ressaut(hRb); % observation de l'ebauche Wb=-hL*UL/(hRb-hL); 
sigBhR=.07*hRb; % erreur d'ebauche, Ref : sigBhR=.07*hRt  (7%)
sigRW=.05*abs(Wt); % erreur d'observation, Ref : sigRW=.05*abs(Wt) (5%)  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% etat vrai
xt=hRt; 

% ebauche
xb=hRb; 

% mesures artificielles a partir de l'etat vrai
E=randn(1,1)-0.5; % erreur gaussienne d'ecart-type 1
yo=calG_ressaut(xt)+sigRW*E;


% matrice B des covariances d'erreurs d'ebauche
B=sigBhR^2;

% matrice R des covariances d'erreurs d'observation 
R=sigRW^2;

% inovation
d=yo-calG_ressaut(xb);

% matrice G de l'operateur d'observation linearise
G=Glin_ressaut(xb);

% Impression des parametres
if(jalea==1)
  disp(sprintf('Etat vrai : hRt=%3.2g, Wt=%3.2g',hRt,Wt))
  disp(sprintf('Ebauche : hRb=%3.2g, Wb=%3.2g',hRb,Wb))
  disp(sprintf('Erreurs ebauche : sigBhR=%3.2g',sigBhR))
  disp(sprintf('Erreur de mesures : sigRW=%3.2g',sigRW))
end





end